
 <template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  >
  </view-grid>
</template>
<script>
import extend from "@/extension/quartzJob/deviceInfo.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "设备信息",
      name: "deviceInfo",
      url: "/DeviceInfo/",
      sortName: "createDate",
    });
    const editFormFields = ref({
      deviceCode: "",
      deviceName: "",
      deviceType: "",
      deviceStatus: "",
      deviceIp: "",
      devicePort: "",
      devicePlcType: "",
      deviceRemark: "",
    });
    const editFormOptions = ref([
      [
        {
          title: "设备编号",
          required: true,
          field: "deviceCode",
          type: "string",
        },
        {
          title: "设备名称",
          required: true,
          field: "deviceName",
          type: "string",
        },
        {
          title: "设备类型",
          required: true,
          field: "deviceType",
          type: "select",
          dataKey: "deviceType",
          data: [],
        },
        {
          title: "设备状态",
          required: true,
          field: "deviceStatus",
          type: "select",
          dataKey: "deviceStatus",
          data: [],
        },
      ],
      [
        { title: "设备IP", required: true, field: "deviceIp", type: "string" },
        {
          title: "设备端口",
          required: true,
          field: "devicePort",
          type: "string",
        },
        {
          title: "PLC类型",
          required: true,
          field: "devicePlcType",
          type: "select",
          dataKey: "devicePlcType",
          data: [],
        },
        {
          title: "备注",
          field: "deviceRemark",
          type: "string",
        },
      ],
    ]);
    const searchFormFields = ref({
      deviceCode: "",
      deviceType: "",
      deviceStatus: "",
    });
    const searchFormOptions = ref([
      [
        { title: "设备编号", field: "deviceCode" },
        {
          title: "设备类型",
          field: "deviceType",
          type: "select",
          dataKey: "deviceType",
          data: [],
        },
        {
          title: "设备状态",
          field: "deviceStatus",
          type: "select",
          dataKey: "deviceStatus",
          data: [],
        },
      ],
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "deviceCode",
        title: "设备编号",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "deviceName",
        title: "设备名称",
        type: "string",
        link: true,
        width: 150,
        align: "left",
      },
      {
        field: "deviceType",
        title: "设备类型",
        type: "string",
        width: 150,
        align: "left",
        bind: { key: "deviceType", data: [] },
      },
      {
        field: "deviceStatus",
        title: "设备状态",
        type: "string",
        width: 90,
        align: "left",
        bind: { key: "deviceStatus", data: [] },
      },
      {
        field: "deviceIp",
        title: "设备IP",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "devicePort",
        title: "设备端口",
        type: "int",
        width: 120,
        align: "left",
      },
      {
        field: "devicePlcType",
        title: "PLC类型",
        type: "string",
        width: 120,
        align: "left",
        bind: { key: "devicePlcType", data: [] },
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "deviceRemark",
        title: "备注",
        type: "string",
        width: 100,
        align: "left",
      },
    ]);
    const detail = ref({
      cnName: "设备协议信息",
      table: "DeviceProtocol",
      columns: [
        {
          field: "id",
          title: "Id",
          type: "int",
          width: 90,
          hidden: true,
          require: true,
          align: "left",
        },
        {
          field: "deviceId",
          title: "设备主键",
          type: "string",
          width: 90,
          hidden: true,
          readonly: true,
          require: true,
          align: "left",
        },
        {
          field: "deviceChildCode",
          title: "设备子编号",
          type: "string",
          edit: { type: "" },
          width: 150,
          require: true,
          align: "left",
          sortable: true,
        },
        {
          field: "deviceProDataBlock",
          title: "协议数据块",
          type: "string",
          width: 100,
          require: true,
          align: "left",
          edit: { type: "" },
        },
        {
          field: "deviceProOffset",
          title: "偏移量",
          type: "decimal",
          width: 90,
          edit: { type: "number" },
          require: true,
          align: "left",
        },
        {
          field: "deviceProDataType",
          title: "数据类型",
          type: "string",
          width: 90,
          require: true,
          align: "left",
          edit: { type: "" },
        },
        {
          field: "deviceProDataLength",
          title: "数据长度",
          type: "int",
          width: 90,
          require: true,
          align: "left",
          edit: { type: "" },
        },
        {
          field: "deviceProParamName",
          title: "参数名称",
          type: "string",
          width: 150,
          require: true,
          align: "left",
          edit: { type: "" },
        },
        {
          field: "deviceProParamType",
          title: "参数类型",
          type: "string",
          width: 150,
          require: true,
          align: "left",
          edit: { type: "" },
        },
        {
          field: "deviceProParamDes",
          title: "参数说明",
          type: "string",
          width: 130,
          require: true,
          align: "left",
          edit: { type: "" },
        },
        {
          field: "creater",
          title: "创建人",
          type: "string",
          width: 90,
          align: "left",
          sortable: true,
        },
        {
          field: "creater",
          title: "创建人",
          type: "string",
          width: 90,
          align: "left",
        },
        {
          field: "createDate",
          title: "创建时间",
          type: "datetime",
          width: 160,
          align: "left",
        },
        {
          field: "modifier",
          title: "修改人",
          type: "string",
          width: 100,
          align: "left",
        },
        {
          field: "modifyDate",
          title: "修改时间",
          type: "datetime",
          width: 160,
          align: "left",
        },
      ],
      sortName: "CreateDate",
      key: "id",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>
